==> payline-java-sdk-4.68-sources.jar: com/payline/ws/model/Sdk.java <==

package com.payline.ws.model;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * 
 *                         This element contains information about SDK.
 *                     
 * 
 * <p>Java class for sdk complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="sdk"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="deviceRenderingOptionsIF" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="deviceRenderOptionsUI" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="appID" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="ephemPubKey" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="maxTimeout" type="{http://www.w3.org/2001/XMLSchema}integer"/&gt;
 *         &lt;element name="referenceNumber" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="transID" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "sdk", namespace = "http://obj.ws.payline.experian.com", propOrder = {
    "deviceRenderingOptionsIF",
    "deviceRenderOptionsUI",
    "appID",
    "ephemPubKey",
    "maxTimeout",
    "referenceNumber",
    "transID"
})
public class Sdk {

    @XmlElement(required = true, nillable = true)
    protected String deviceRenderingOptionsIF;
    @XmlElement(required = true, nillable = true)
    protected String deviceRenderOptionsUI;
    @XmlElement(required = true, nillable = true)
    protected String appID;
    @XmlElement(required = true, nillable = true)
    protected String ephemPubKey;
    @XmlElement(required = true, nillable = true)
    protected BigInteger maxTimeout;
    @XmlElement(required = true, nillable = true)
    protected String referenceNumber;
    @XmlElement(required = true, nillable = true)
    protected String transID;

    /**
     * Gets the value of the deviceRenderingOptionsIF property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDeviceRenderingOptionsIF() {
        return deviceRenderingOptionsIF;
    }

    /**
     * Sets the value of the deviceRenderingOptionsIF property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDeviceRenderingOptionsIF(String value) {
        this.deviceRenderingOptionsIF = value;
    }

    /**
     * Gets the value of the deviceRenderOptionsUI property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDeviceRenderOptionsUI() {
        return deviceRenderOptionsUI;
    }

    /**
     * Sets the value of the deviceRenderOptionsUI property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDeviceRenderOptionsUI(String value) {
        this.deviceRenderOptionsUI = value;
    }

    /**
     * Gets the value of the appID property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAppID() {
        return appID;
    }

    /**
     * Sets the value of the appID property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAppID(String value) {
        this.appID = value;
    }

    /**
     * Gets the value of the ephemPubKey property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEphemPubKey() {
        return ephemPubKey;
    }

    /**
     * Sets the value of the ephemPubKey property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEphemPubKey(String value) {
        this.ephemPubKey = value;
    }

    /**
     * Gets the value of the maxTimeout property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getMaxTimeout() {
        return maxTimeout;
    }

    /**
     * Sets the value of the maxTimeout property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setMaxTimeout(BigInteger value) {
        this.maxTimeout = value;
    }

    /**
     * Gets the value of the referenceNumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getReferenceNumber() {
        return referenceNumber;
    }

    /**
     * Sets the value of the referenceNumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setReferenceNumber(String value) {
        this.referenceNumber = value;
    }

    /**
     * Gets the value of the transID property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTransID() {
        return transID;
    }

    /**
     * Sets the value of the transID property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTransID(String value) {
        this.transID = value;
    }

}

==> payline-java-sdk-4.71-sources.jar: com/payline/ws/model/Sdk.java <==

package com.payline.ws.model;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * 
 *                         This element contains information about SDK.
 *                     
 * 
 * <p>Java class for sdk complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="sdk"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="deviceRenderingOptionsIF" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="deviceRenderOptionsUI" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="appID" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="ephemPubKey" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="maxTimeout" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="referenceNumber" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="transID" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="encData" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "sdk", namespace = "http://obj.ws.payline.experian.com", propOrder = {
    "deviceRenderingOptionsIF",
    "deviceRenderOptionsUI",
    "appID",
    "ephemPubKey",
    "maxTimeout",
    "referenceNumber",
    "transID",
    "encData"
})
public class Sdk {

    @XmlElement(required = true, nillable = true)
    protected String deviceRenderingOptionsIF;
    @XmlElement(required = true, nillable = true)
    protected String deviceRenderOptionsUI;
    @XmlElement(required = true, nillable = true)
    protected String appID;
    @XmlElement(required = true, nillable = true)
    protected String ephemPubKey;
    @XmlElement(required = true, nillable = true)
    protected String maxTimeout;
    @XmlElement(required = true, nillable = true)
    protected String referenceNumber;
    @XmlElement(required = true, nillable = true)
    protected String transID;
    @XmlElement(required = true, nillable = true)
    protected String encData;

    /**
     * Gets the value of the deviceRenderingOptionsIF property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDeviceRenderingOptionsIF() {
        return deviceRenderingOptionsIF;
    }

    /**
     * Sets the value of the deviceRenderingOptionsIF property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDeviceRenderingOptionsIF(String value) {
        this.deviceRenderingOptionsIF = value;
    }

    /**
     * Gets the value of the deviceRenderOptionsUI property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDeviceRenderOptionsUI() {
        return deviceRenderOptionsUI;
    }

    /**
     * Sets the value of the deviceRenderOptionsUI property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDeviceRenderOptionsUI(String value) {
        this.deviceRenderOptionsUI = value;
    }

    /**
     * Gets the value of the appID property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAppID() {
        return appID;
    }

    /**
     * Sets the value of the appID property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAppID(String value) {
        this.appID = value;
    }

    /**
     * Gets the value of the ephemPubKey property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEphemPubKey() {
        return ephemPubKey;
    }

    /**
     * Sets the value of the ephemPubKey property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEphemPubKey(String value) {
        this.ephemPubKey = value;
    }

    /**
     * Gets the value of the maxTimeout property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMaxTimeout() {
        return maxTimeout;
    }

    /**
     * Sets the value of the maxTimeout property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMaxTimeout(String value) {
        this.maxTimeout = value;
    }

    /**
     * Gets the value of the referenceNumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getReferenceNumber() {
        return referenceNumber;
    }

    /**
     * Sets the value of the referenceNumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setReferenceNumber(String value) {
        this.referenceNumber = value;
    }

    /**
     * Gets the value of the transID property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTransID() {
        return transID;
    }

    /**
     * Sets the value of the transID property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTransID(String value) {
        this.transID = value;
    }

    /**
     * Gets the value of the encData property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEncData() {
        return encData;
    }

    /**
     * Sets the value of the encData property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEncData(String value) {
        this.encData = value;
    }

}
